@@ -1,4 +1,4 @@
-#!/bin/sh
+#!/bin/bash
 
 . /usr/libexec/rc/sh/functions.sh
 
@@ -27,7 +27,7 @@ done
 
 case $1 in
 	start)
-		cp -pr "$cachedir"/* "$_svcdir" 2>/dev/null
+		cp -pr "$cachedir"/* "$svcdir" 2>/dev/null
 		openrc --user boot || exit 1
 		printf '\n' >&3
 		exec openrc --user "${rc_default_runlevel:-default}"
